@@ -11,40 +11,42 @@ def align():
 
 
 def armature_layers(
-        layers: bool = (False, False, False, False, False, False, False, False,
-                        False, False, False, False, False, False, False, False,
-                        False, False, False, False, False, False, False, False,
-                        False, False, False, False, False, False, False,
-                        False)):
+        layers: typing.List[bool] = (False, False, False, False, False, False,
+                                     False, False, False, False, False, False,
+                                     False, False, False, False, False, False,
+                                     False, False, False, False, False, False,
+                                     False, False, False, False, False, False,
+                                     False, False)):
     '''Change the visible armature layers 
 
     :param layers: Layer, Armature layers to make visible 
-    :type layers: bool
+    :type layers: typing.List[bool]
     '''
 
     pass
 
 
-def autoside_names(type: int = 'XAXIS'):
+def autoside_names(type: typing.Union[int, str] = 'XAXIS'):
     '''Automatically renames the selected bones according to which side of the target axis they fall on 
 
     :param type: Axis, Axis tag names withXAXIS X-Axis, Left/Right.YAXIS Y-Axis, Front/Back.ZAXIS Z-Axis, Top/Bottom. 
-    :type type: int
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
 def bone_layers(
-        layers: bool = (False, False, False, False, False, False, False, False,
-                        False, False, False, False, False, False, False, False,
-                        False, False, False, False, False, False, False, False,
-                        False, False, False, False, False, False, False,
-                        False)):
+        layers: typing.List[bool] = (False, False, False, False, False, False,
+                                     False, False, False, False, False, False,
+                                     False, False, False, False, False, False,
+                                     False, False, False, False, False, False,
+                                     False, False, False, False, False, False,
+                                     False, False)):
     '''Change the layers that the selected bones belong to 
 
     :param layers: Layer, Armature layers that bone belongs to 
-    :type layers: bool
+    :type layers: typing.List[bool]
     '''
 
     pass
@@ -60,13 +62,13 @@ def bone_primitive_add(name: str = "Bone"):
     pass
 
 
-def calculate_roll(type: int = 'POS_X',
+def calculate_roll(type: typing.Union[int, str] = 'POS_X',
                    axis_flip: bool = False,
                    axis_only: bool = False):
     '''Automatically fix alignment of select bones’ axes 
 
     :param type: Type 
-    :type type: int
+    :type type: typing.Union[int, str]
     :param axis_flip: Flip Axis, Negate the alignment axis 
     :type axis_flip: bool
     :param axis_only: Shortest Rotation, Ignore the axis direction, use the shortest rotation to align 
@@ -184,31 +186,31 @@ def layers_show_all(all: bool = True):
     pass
 
 
-def merge(type: int = 'WITHIN_CHAIN'):
+def merge(type: typing.Union[int, str] = 'WITHIN_CHAIN'):
     '''Merge continuous chains of selected bones 
 
     :param type: Type 
-    :type type: int
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
-def parent_clear(type: int = 'CLEAR'):
+def parent_clear(type: typing.Union[int, str] = 'CLEAR'):
     '''Remove the parent-child relationship between selected bones and their parents 
 
     :param type: ClearType, What way to clear parenting 
-    :type type: int
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
-def parent_set(type: int = 'CONNECTED'):
+def parent_set(type: typing.Union[int, str] = 'CONNECTED'):
     '''Set the active bone as the parent of the selected bones 
 
     :param type: ParentType, Type of parenting 
-    :type type: int
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -232,21 +234,22 @@ def roll_clear(roll: float = 0.0):
     pass
 
 
-def select_all(action: int = 'TOGGLE'):
+def select_all(action: typing.Union[int, str] = 'TOGGLE'):
     '''Toggle selection status of all bones 
 
     :param action: Action, Selection action to executeTOGGLE Toggle, Toggle selection for all elements.SELECT Select, Select all elements.DESELECT Deselect, Deselect all elements.INVERT Invert, Invert selection of all elements. 
-    :type action: int
+    :type action: typing.Union[int, str]
     '''
 
     pass
 
 
-def select_hierarchy(direction: int = 'PARENT', extend: bool = False):
+def select_hierarchy(direction: typing.Union[int, str] = 'PARENT',
+                     extend: bool = False):
     '''Select immediate parent/children of selected bones 
 
     :param direction: Direction 
-    :type direction: int
+    :type direction: typing.Union[int, str]
     :param extend: Extend, Extend the selection 
     :type extend: bool
     '''
@@ -292,11 +295,12 @@ def select_more():
     pass
 
 
-def select_similar(type: int = 'LENGTH', threshold: float = 0.1):
+def select_similar(type: typing.Union[int, str] = 'LENGTH',
+                   threshold: float = 0.1):
     '''Select similar bones by property types 
 
     :param type: Type 
-    :type type: int
+    :type type: typing.Union[int, str]
     :param threshold: Threshold 
     :type threshold: float
     '''
@@ -346,11 +350,11 @@ def switch_direction():
     pass
 
 
-def symmetrize(direction: int = 'NEGATIVE_X'):
+def symmetrize(direction: typing.Union[int, str] = 'NEGATIVE_X'):
     '''Enforce symmetry, make copies of the selection or use existing 
 
     :param direction: Direction, Which sides to copy from and to (when both are selected) 
-    :type direction: int
+    :type direction: typing.Union[int, str]
     '''
 
     pass
