@@ -54,11 +54,11 @@ def copy_as_script():
     pass
 
 
-def delete(type: int = 'NEXT_CHARACTER'):
+def delete(type: typing.Union[int, str] = 'NEXT_CHARACTER'):
     '''Delete text by cursor position 
 
     :param type: Type, Which part of the text to delete 
-    :type type: int
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -128,11 +128,11 @@ def language(language: str = ""):
     pass
 
 
-def move(type: int = 'LINE_BEGIN'):
+def move(type: typing.Union[int, str] = 'LINE_BEGIN'):
     '''Move cursor position 
 
     :param type: Type, Where to move cursor to 
-    :type type: int
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -146,13 +146,13 @@ def paste():
     pass
 
 
-def scrollback_append(text: str = "", type: int = 'OUTPUT'):
+def scrollback_append(text: str = "", type: typing.Union[int, str] = 'OUTPUT'):
     '''Append scrollback text by type 
 
     :param text: Text, Text to insert at the cursor position 
     :type text: str
     :param type: Type, Console output type 
-    :type type: int
+    :type type: typing.Union[int, str]
     '''
 
     pass
