@@ -1,13 +1,12 @@
 import sys
 import typing
-import bpy
 
 
-def cyclic_toggle(direction: int = 'CYCLIC_U'):
+def cyclic_toggle(direction: typing.Union[int, str] = 'CYCLIC_U'):
     '''Make active spline closed/opened loop 
 
     :param direction: Direction, Direction to make surface cyclic in 
-    :type direction: int
+    :type direction: typing.Union[int, str]
     '''
 
     pass
@@ -29,11 +28,11 @@ def de_select_last():
     pass
 
 
-def delete(type: int = 'VERT'):
+def delete(type: typing.Union[int, str] = 'VERT'):
     '''Delete selected control points or segments 
 
     :param type: Type, Which elements to delete 
-    :type type: int
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -48,23 +47,24 @@ def dissolve_verts():
 
 
 def draw(error_threshold: float = 0.0,
-         fit_method: int = 'REFIT',
+         fit_method: typing.Union[int, str] = 'REFIT',
          corner_angle: float = 1.22173,
          use_cyclic: bool = True,
-         stroke: typing.List['bpy.types.OperatorStrokeElement'] = None,
+         stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
+                              'bpy_prop_collection'] = None,
          wait_for_input: bool = True):
     '''Draw a freehand spline 
 
     :param error_threshold: Error, Error distance threshold (in object units) 
     :type error_threshold: float
     :param fit_method: Fit MethodREFIT Refit, Incrementally re-fit the curve (high quality).SPLIT Split, Split the curve until the tolerance is met (fast). 
-    :type fit_method: int
+    :type fit_method: typing.Union[int, str]
     :param corner_angle: Corner Angle 
     :type corner_angle: float
     :param use_cyclic: Cyclic 
     :type use_cyclic: bool
     :param stroke: Stroke 
-    :type stroke: typing.List['bpy.types.OperatorStrokeElement']
+    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param wait_for_input: Wait for Input 
     :type wait_for_input: bool
     '''
@@ -90,11 +90,11 @@ def duplicate_move(CURVE_OT_duplicate=None, TRANSFORM_OT_translate=None):
     pass
 
 
-def extrude(mode: int = 'TRANSLATION'):
+def extrude(mode: typing.Union[int, str] = 'TRANSLATION'):
     '''Extrude selected control point(s) 
 
     :param mode: Mode 
-    :type mode: int
+    :type mode: typing.Union[int, str]
     '''
 
     pass
@@ -110,11 +110,11 @@ def extrude_move(CURVE_OT_extrude=None, TRANSFORM_OT_translate=None):
     pass
 
 
-def handle_type_set(type: int = 'AUTOMATIC'):
+def handle_type_set(type: typing.Union[int, str] = 'AUTOMATIC'):
     '''Set type of handles for selected control points 
 
     :param type: Type, Spline type 
-    :type type: int
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -160,11 +160,12 @@ def primitive_bezier_circle_add(
         radius: float = 1.0,
         view_align: bool = False,
         enter_editmode: bool = False,
-        location: float = (0.0, 0.0, 0.0),
-        rotation: float = (0.0, 0.0, 0.0),
-        layers: bool = (False, False, False, False, False, False, False, False,
-                        False, False, False, False, False, False, False, False,
-                        False, False, False, False)):
+        location: typing.List[float] = (0.0, 0.0, 0.0),
+        rotation: typing.List[float] = (0.0, 0.0, 0.0),
+        layers: typing.List[bool] = (False, False, False, False, False, False,
+                                     False, False, False, False, False, False,
+                                     False, False, False, False, False, False,
+                                     False, False)):
     '''Construct a Bezier Circle 
 
     :param radius: Radius 
@@ -174,11 +175,11 @@ def primitive_bezier_circle_add(
     :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
     :type enter_editmode: bool
     :param location: Location, Location for the newly added object 
-    :type location: float
+    :type location: typing.List[float]
     :param rotation: Rotation, Rotation for the newly added object 
-    :type rotation: float
+    :type rotation: typing.List[float]
     :param layers: Layer 
-    :type layers: bool
+    :type layers: typing.List[bool]
     '''
 
     pass
@@ -188,11 +189,12 @@ def primitive_bezier_curve_add(
         radius: float = 1.0,
         view_align: bool = False,
         enter_editmode: bool = False,
-        location: float = (0.0, 0.0, 0.0),
-        rotation: float = (0.0, 0.0, 0.0),
-        layers: bool = (False, False, False, False, False, False, False, False,
-                        False, False, False, False, False, False, False, False,
-                        False, False, False, False)):
+        location: typing.List[float] = (0.0, 0.0, 0.0),
+        rotation: typing.List[float] = (0.0, 0.0, 0.0),
+        layers: typing.List[bool] = (False, False, False, False, False, False,
+                                     False, False, False, False, False, False,
+                                     False, False, False, False, False, False,
+                                     False, False)):
     '''Construct a Bezier Curve 
 
     :param radius: Radius 
@@ -202,11 +204,11 @@ def primitive_bezier_curve_add(
     :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
     :type enter_editmode: bool
     :param location: Location, Location for the newly added object 
-    :type location: float
+    :type location: typing.List[float]
     :param rotation: Rotation, Rotation for the newly added object 
-    :type rotation: float
+    :type rotation: typing.List[float]
     :param layers: Layer 
-    :type layers: bool
+    :type layers: typing.List[bool]
     '''
 
     pass
@@ -216,11 +218,12 @@ def primitive_nurbs_circle_add(
         radius: float = 1.0,
         view_align: bool = False,
         enter_editmode: bool = False,
-        location: float = (0.0, 0.0, 0.0),
-        rotation: float = (0.0, 0.0, 0.0),
-        layers: bool = (False, False, False, False, False, False, False, False,
-                        False, False, False, False, False, False, False, False,
-                        False, False, False, False)):
+        location: typing.List[float] = (0.0, 0.0, 0.0),
+        rotation: typing.List[float] = (0.0, 0.0, 0.0),
+        layers: typing.List[bool] = (False, False, False, False, False, False,
+                                     False, False, False, False, False, False,
+                                     False, False, False, False, False, False,
+                                     False, False)):
     '''Construct a Nurbs Circle 
 
     :param radius: Radius 
@@ -230,11 +233,11 @@ def primitive_nurbs_circle_add(
     :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
     :type enter_editmode: bool
     :param location: Location, Location for the newly added object 
-    :type location: float
+    :type location: typing.List[float]
     :param rotation: Rotation, Rotation for the newly added object 
-    :type rotation: float
+    :type rotation: typing.List[float]
     :param layers: Layer 
-    :type layers: bool
+    :type layers: typing.List[bool]
     '''
 
     pass
@@ -244,11 +247,12 @@ def primitive_nurbs_curve_add(
         radius: float = 1.0,
         view_align: bool = False,
         enter_editmode: bool = False,
-        location: float = (0.0, 0.0, 0.0),
-        rotation: float = (0.0, 0.0, 0.0),
-        layers: bool = (False, False, False, False, False, False, False, False,
-                        False, False, False, False, False, False, False, False,
-                        False, False, False, False)):
+        location: typing.List[float] = (0.0, 0.0, 0.0),
+        rotation: typing.List[float] = (0.0, 0.0, 0.0),
+        layers: typing.List[bool] = (False, False, False, False, False, False,
+                                     False, False, False, False, False, False,
+                                     False, False, False, False, False, False,
+                                     False, False)):
     '''Construct a Nurbs Curve 
 
     :param radius: Radius 
@@ -258,11 +262,11 @@ def primitive_nurbs_curve_add(
     :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
     :type enter_editmode: bool
     :param location: Location, Location for the newly added object 
-    :type location: float
+    :type location: typing.List[float]
     :param rotation: Rotation, Rotation for the newly added object 
-    :type rotation: float
+    :type rotation: typing.List[float]
     :param layers: Layer 
-    :type layers: bool
+    :type layers: typing.List[bool]
     '''
 
     pass
@@ -272,11 +276,12 @@ def primitive_nurbs_path_add(
         radius: float = 1.0,
         view_align: bool = False,
         enter_editmode: bool = False,
-        location: float = (0.0, 0.0, 0.0),
-        rotation: float = (0.0, 0.0, 0.0),
-        layers: bool = (False, False, False, False, False, False, False, False,
-                        False, False, False, False, False, False, False, False,
-                        False, False, False, False)):
+        location: typing.List[float] = (0.0, 0.0, 0.0),
+        rotation: typing.List[float] = (0.0, 0.0, 0.0),
+        layers: typing.List[bool] = (False, False, False, False, False, False,
+                                     False, False, False, False, False, False,
+                                     False, False, False, False, False, False,
+                                     False, False)):
     '''Construct a Path 
 
     :param radius: Radius 
@@ -286,11 +291,11 @@ def primitive_nurbs_path_add(
     :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
     :type enter_editmode: bool
     :param location: Location, Location for the newly added object 
-    :type location: float
+    :type location: typing.List[float]
     :param rotation: Rotation, Rotation for the newly added object 
-    :type rotation: float
+    :type rotation: typing.List[float]
     :param layers: Layer 
-    :type layers: bool
+    :type layers: typing.List[bool]
     '''
 
     pass
@@ -314,11 +319,11 @@ def reveal():
     pass
 
 
-def select_all(action: int = 'TOGGLE'):
+def select_all(action: typing.Union[int, str] = 'TOGGLE'):
     '''(De)select all control points 
 
     :param action: Action, Selection action to executeTOGGLE Toggle, Toggle selection for all elements.SELECT Select, Select all elements.DESELECT Deselect, Deselect all elements.INVERT Invert, Invert selection of all elements. 
-    :type action: int
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -388,8 +393,9 @@ def select_previous():
     pass
 
 
-def select_random(percent: float = 50.0, seed: int = 0,
-                  action: int = 'SELECT'):
+def select_random(percent: float = 50.0,
+                  seed: int = 0,
+                  action: typing.Union[int, str] = 'SELECT'):
     '''Randomly select some control points 
 
     :param percent: Percent, Percentage of objects to select randomly 
@@ -397,7 +403,7 @@ def select_random(percent: float = 50.0, seed: int = 0,
     :param seed: Random Seed, Seed for the random number generator 
     :type seed: int
     :param action: Action, Selection action to executeSELECT Select, Select all elements.DESELECT Deselect, Deselect all elements. 
-    :type action: int
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -411,15 +417,15 @@ def select_row():
     pass
 
 
-def select_similar(type: int = 'WEIGHT',
-                   compare: int = 'EQUAL',
+def select_similar(type: typing.Union[int, str] = 'WEIGHT',
+                   compare: typing.Union[int, str] = 'EQUAL',
                    threshold: float = 0.1):
     '''Select similar curve points by property type 
 
     :param type: Type 
-    :type type: int
+    :type type: typing.Union[int, str]
     :param compare: Compare 
-    :type compare: int
+    :type compare: typing.Union[int, str]
     :param threshold: Threshold 
     :type threshold: float
     '''
@@ -491,23 +497,25 @@ def smooth_weight():
     pass
 
 
-def spin(center: float = (0.0, 0.0, 0.0), axis: float = (0.0, 0.0, 0.0)):
+def spin(center: typing.List[float] = (0.0, 0.0, 0.0),
+         axis: typing.List[float] = (0.0, 0.0, 0.0)):
     '''Extrude selected boundary row around pivot point and current view axis 
 
     :param center: Center, Center in global view space 
-    :type center: float
+    :type center: typing.List[float]
     :param axis: Axis, Axis in global view space 
-    :type axis: float
+    :type axis: typing.List[float]
     '''
 
     pass
 
 
-def spline_type_set(type: int = 'POLY', use_handles: bool = False):
+def spline_type_set(type: typing.Union[int, str] = 'POLY',
+                    use_handles: bool = False):
     '''Set type of active spline 
 
     :param type: Type, Spline type 
-    :type type: int
+    :type type: typing.Union[int, str]
     :param use_handles: Handles, Use handles when converting bezier curves into polygons 
     :type use_handles: bool
     '''
@@ -559,11 +567,11 @@ def tilt_clear():
     pass
 
 
-def vertex_add(location: float = (0.0, 0.0, 0.0)):
+def vertex_add(location: typing.List[float] = (0.0, 0.0, 0.0)):
     '''Add a new control point (linked to only selected end-curve one, if any) 
 
     :param location: Location, Location to add new vertex at 
-    :type location: float
+    :type location: typing.List[float]
     '''
 
     pass
