@@ -1,6 +1,5 @@
 import sys
 import typing
-import bpy
 
 
 def change_frame(frame: int = 0):
@@ -21,11 +20,11 @@ def clear_render_border():
     pass
 
 
-def curves_point_set(point: int = 'BLACK_POINT'):
+def curves_point_set(point: typing.Union[int, str] = 'BLACK_POINT'):
     '''Set black point or white point for curves 
 
     :param point: Point, Set black point or white point for curves 
-    :type point: int
+    :type point: typing.Union[int, str]
     '''
 
     pass
@@ -81,11 +80,11 @@ def match_movie_length():
 def new(name: str = "Untitled",
         width: int = 1024,
         height: int = 1024,
-        color: float = (0.0, 0.0, 0.0, 1.0),
+        color: typing.List[float] = (0.0, 0.0, 0.0, 1.0),
         alpha: bool = True,
-        generated_type: int = 'BLANK',
+        generated_type: typing.Union[int, str] = 'BLANK',
         float: bool = False,
-        gen_context: int = 'NONE',
+        gen_context: typing.Union[int, str] = 'NONE',
         use_stereo_3d: bool = False):
     '''Create a new image 
 
@@ -96,15 +95,15 @@ def new(name: str = "Untitled",
     :param height: Height, Image height 
     :type height: int
     :param color: Color, Default fill color 
-    :type color: float
+    :type color: typing.List[float]
     :param alpha: Alpha, Create an image with an alpha channel 
     :type alpha: bool
     :param generated_type: Generated Type, Fill the image with a grid for UV map testingBLANK Blank, Generate a blank image.UV_GRID UV Grid, Generated grid to test UV mappings.COLOR_GRID Color Grid, Generated improved UV grid to test UV mappings. 
-    :type generated_type: int
+    :type generated_type: typing.Union[int, str]
     :param float: 32 bit Float, Create image with 32 bit floating point bit depth 
     :type float: bool
     :param gen_context: Gen Context, Generation context 
-    :type gen_context: int
+    :type gen_context: typing.Union[int, str]
     :param use_stereo_3d: Stereo 3D, Create an image with left and right views 
     :type use_stereo_3d: bool
     '''
@@ -114,7 +113,8 @@ def new(name: str = "Untitled",
 
 def open(filepath: str = "",
          directory: str = "",
-         files: typing.List['bpy.types.OperatorFileListElement'] = None,
+         files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                             'bpy_prop_collection'] = None,
          filter_blender: bool = False,
          filter_backup: bool = False,
          filter_image: bool = True,
@@ -132,8 +132,8 @@ def open(filepath: str = "",
          relative_path: bool = True,
          show_multiview: bool = False,
          use_multiview: bool = False,
-         display_type: int = 'DEFAULT',
-         sort_method: int = 'FILE_SORT_ALPHA'):
+         display_type: typing.Union[int, str] = 'DEFAULT',
+         sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
     '''Open image 
 
     :param filepath: File Path, Path to file 
@@ -141,7 +141,7 @@ def open(filepath: str = "",
     :param directory: Directory, Directory of the file 
     :type directory: str
     :param files: Files 
-    :type files: typing.List['bpy.types.OperatorFileListElement']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files 
     :type filter_blender: bool
     :param filter_backup: Filter .blend files 
@@ -177,9 +177,9 @@ def open(filepath: str = "",
     :param use_multiview: Use Multi-View 
     :type use_multiview: bool
     :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
-    :type display_type: int
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
-    :type sort_method: int
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
@@ -269,8 +269,8 @@ def replace(filepath: str = "",
             relative_path: bool = True,
             show_multiview: bool = False,
             use_multiview: bool = False,
-            display_type: int = 'DEFAULT',
-            sort_method: int = 'FILE_SORT_ALPHA'):
+            display_type: typing.Union[int, str] = 'DEFAULT',
+            sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
     '''Replace current image by another one from disk 
 
     :param filepath: File Path, Path to file 
@@ -310,9 +310,9 @@ def replace(filepath: str = "",
     :param use_multiview: Use Multi-View 
     :type use_multiview: bool
     :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
-    :type display_type: int
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
-    :type sort_method: int
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
@@ -377,8 +377,8 @@ def save_as(save_as_render: bool = False,
             relative_path: bool = True,
             show_multiview: bool = False,
             use_multiview: bool = False,
-            display_type: int = 'DEFAULT',
-            sort_method: int = 'FILE_SORT_ALPHA'):
+            display_type: typing.Union[int, str] = 'DEFAULT',
+            sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
     '''Save the image with another name and/or settings 
 
     :param save_as_render: Save As Render, Apply render part of display transform when saving byte image 
@@ -424,9 +424,9 @@ def save_as(save_as_render: bool = False,
     :param use_multiview: Use Multi-View 
     :type use_multiview: bool
     :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
-    :type display_type: int
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
-    :type sort_method: int
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
@@ -456,11 +456,11 @@ def toolshelf():
     pass
 
 
-def unpack(method: int = 'USE_LOCAL', id: str = ""):
+def unpack(method: typing.Union[int, str] = 'USE_LOCAL', id: str = ""):
     '''Save an image packed in the .blend file to disk 
 
     :param method: Method, How to unpack 
-    :type method: int
+    :type method: typing.Union[int, str]
     :param id: Image Name, Image datablock name to unpack 
     :type id: str
     '''
@@ -486,11 +486,11 @@ def view_ndof():
     pass
 
 
-def view_pan(offset: float = (0.0, 0.0)):
+def view_pan(offset: typing.List[float] = (0.0, 0.0)):
     '''Pan the view 
 
     :param offset: Offset, Offset in floating point units, 1.0 is the width and height of the image 
-    :type offset: float
+    :type offset: typing.List[float]
     '''
 
     pass
@@ -536,21 +536,21 @@ def view_zoom_border(gesture_mode: int = 0,
     pass
 
 
-def view_zoom_in(location: float = (0.0, 0.0)):
+def view_zoom_in(location: typing.List[float] = (0.0, 0.0)):
     '''Zoom in the image (centered around 2D cursor) 
 
     :param location: Location, Cursor location in screen coordinates 
-    :type location: float
+    :type location: typing.List[float]
     '''
 
     pass
 
 
-def view_zoom_out(location: float = (0.0, 0.0)):
+def view_zoom_out(location: typing.List[float] = (0.0, 0.0)):
     '''Zoom out the image (centered around 2D cursor) 
 
     :param location: Location, Cursor location in screen coordinates 
-    :type location: float
+    :type location: typing.List[float]
     '''
 
     pass
