@@ -1,10 +1,10 @@
 import sys
 import typing
-import bpy
 
 
 def ply(filepath: str = "",
-        files: typing.List['bpy.types.OperatorFileListElement'] = None,
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
         directory: str = "",
         filter_glob: str = "*.ply"):
     '''Load a PLY geometry file 
@@ -12,7 +12,7 @@ def ply(filepath: str = "",
     :param filepath: File Path, Filepath used for importing the file 
     :type filepath: str
     :param files: File Path, File path used for importing the PLY file 
-    :type files: typing.List['bpy.types.OperatorFileListElement']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param directory: directory 
     :type directory: str
     :param filter_glob: filter_glob 
@@ -23,10 +23,11 @@ def ply(filepath: str = "",
 
 
 def stl(filepath: str = "",
-        axis_forward: int = 'Y',
-        axis_up: int = 'Z',
+        axis_forward: typing.Union[int, str] = 'Y',
+        axis_up: typing.Union[int, str] = 'Z',
         filter_glob: str = "*.stl",
-        files: typing.List['bpy.types.OperatorFileListElement'] = None,
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
         directory: str = "",
         global_scale: float = 1.0,
         use_scene_unit: bool = False,
@@ -36,13 +37,13 @@ def stl(filepath: str = "",
     :param filepath: File Path, Filepath used for importing the file 
     :type filepath: str
     :param axis_forward: Forward 
-    :type axis_forward: int
+    :type axis_forward: typing.Union[int, str]
     :param axis_up: Up 
-    :type axis_up: int
+    :type axis_up: typing.Union[int, str]
     :param filter_glob: filter_glob 
     :type filter_glob: str
     :param files: File Path 
-    :type files: typing.List['bpy.types.OperatorFileListElement']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param directory: directory 
     :type directory: str
     :param global_scale: Scale 
