@@ -1,13 +1,12 @@
 import sys
 import typing
-import bpy
 
 
-def add_feather_vertex(location: float = (0.0, 0.0)):
+def add_feather_vertex(location: typing.List[float] = (0.0, 0.0)):
     '''Add vertex to feather 
 
     :param location: Location, Location of vertex in normalized space 
-    :type location: float
+    :type location: typing.List[float]
     '''
 
     pass
@@ -24,11 +23,11 @@ def add_feather_vertex_slide(MASK_OT_add_feather_vertex=None,
     pass
 
 
-def add_vertex(location: float = (0.0, 0.0)):
+def add_vertex(location: typing.List[float] = (0.0, 0.0)):
     '''Add vertex to active spline 
 
     :param location: Location, Location of vertex in normalized space 
-    :type location: float
+    :type location: typing.List[float]
     '''
 
     pass
@@ -94,11 +93,11 @@ def feather_weight_clear():
     pass
 
 
-def handle_type_set(type: int = 'AUTO'):
+def handle_type_set(type: typing.Union[int, str] = 'AUTO'):
     '''Set type of handles for selected control points 
 
     :param type: Type, Spline type 
-    :type type: int
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -122,11 +121,11 @@ def hide_view_set(unselected: bool = False):
     pass
 
 
-def layer_move(direction: int = 'UP'):
+def layer_move(direction: typing.Union[int, str] = 'UP'):
     '''Move the active layer up/down in the list 
 
     :param direction: Direction, Direction to move the active layer 
-    :type direction: int
+    :type direction: typing.Union[int, str]
     '''
 
     pass
@@ -192,25 +191,27 @@ def paste_splines():
     pass
 
 
-def primitive_circle_add(size: float = 100.0, location: float = (0.0, 0.0)):
+def primitive_circle_add(size: float = 100.0,
+                         location: typing.List[float] = (0.0, 0.0)):
     '''Add new circle-shaped spline 
 
     :param size: Size, Size of new circle 
     :type size: float
     :param location: Location, Location of new circle 
-    :type location: float
+    :type location: typing.List[float]
     '''
 
     pass
 
 
-def primitive_square_add(size: float = 100.0, location: float = (0.0, 0.0)):
+def primitive_square_add(size: float = 100.0,
+                         location: typing.List[float] = (0.0, 0.0)):
     '''Add new square-shaped spline 
 
     :param size: Size, Size of new circle 
     :type size: float
     :param location: Location, Location of new circle 
-    :type location: float
+    :type location: typing.List[float]
     '''
 
     pass
@@ -219,7 +220,7 @@ def primitive_square_add(size: float = 100.0, location: float = (0.0, 0.0)):
 def select(extend: bool = False,
            deselect: bool = False,
            toggle: bool = False,
-           location: float = (0.0, 0.0)):
+           location: typing.List[float] = (0.0, 0.0)):
     '''Select spline points 
 
     :param extend: Extend, Extend selection instead of deselecting everything first 
@@ -229,17 +230,17 @@ def select(extend: bool = False,
     :param toggle: Toggle Selection, Toggle the selection 
     :type toggle: bool
     :param location: Location, Location of vertex in normalized space 
-    :type location: float
+    :type location: typing.List[float]
     '''
 
     pass
 
 
-def select_all(action: int = 'TOGGLE'):
+def select_all(action: typing.Union[int, str] = 'TOGGLE'):
     '''Change selection of all curve points 
 
     :param action: Action, Selection action to executeTOGGLE Toggle, Toggle selection for all elements.SELECT Select, Select all elements.DESELECT Deselect, Deselect all elements.INVERT Invert, Invert selection of all elements. 
-    :type action: int
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -289,13 +290,14 @@ def select_circle(x: int = 0,
     pass
 
 
-def select_lasso(path: typing.List['bpy.types.OperatorMousePath'] = None,
+def select_lasso(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
+                                    'bpy_prop_collection'] = None,
                  deselect: bool = False,
                  extend: bool = True):
     '''Select curve points using lasso selection 
 
     :param path: Path 
-    :type path: typing.List['bpy.types.OperatorMousePath']
+    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param deselect: Deselect, Deselect rather than select items 
     :type deselect: bool
     :param extend: Extend, Extend selection instead of deselecting everything first 
