@@ -1,6 +1,5 @@
 import sys
 import typing
-import bpy
 
 
 def add_simple_uvs():
@@ -11,18 +10,18 @@ def add_simple_uvs():
     pass
 
 
-def add_texture_paint_slot(type: int = 'DIFFUSE_COLOR',
+def add_texture_paint_slot(type: typing.Union[int, str] = 'DIFFUSE_COLOR',
                            name: str = "Untitled",
                            width: int = 1024,
                            height: int = 1024,
-                           color: float = (0.0, 0.0, 0.0, 1.0),
+                           color: typing.List[float] = (0.0, 0.0, 0.0, 1.0),
                            alpha: bool = True,
-                           generated_type: int = 'BLANK',
+                           generated_type: typing.Union[int, str] = 'BLANK',
                            float: bool = False):
     '''Add a texture paint slot 
 
     :param type: Type, Merge method to use 
-    :type type: int
+    :type type: typing.Union[int, str]
     :param name: Name, Image datablock name 
     :type name: str
     :param width: Width, Image width 
@@ -30,11 +29,11 @@ def add_texture_paint_slot(type: int = 'DIFFUSE_COLOR',
     :param height: Height, Image height 
     :type height: int
     :param color: Color, Default fill color 
-    :type color: float
+    :type color: typing.List[float]
     :param alpha: Alpha, Create an image with an alpha channel 
     :type alpha: bool
     :param generated_type: Generated Type, Fill the image with a grid for UV map testingBLANK Blank, Generate a blank image.UV_GRID UV Grid, Generated grid to test UV mappings.COLOR_GRID Color Grid, Generated improved UV grid to test UV mappings. 
-    :type generated_type: int
+    :type generated_type: typing.Union[int, str]
     :param float: 32 bit Float, Create image with 32 bit floating point bit depth 
     :type float: bool
     '''
@@ -50,25 +49,25 @@ def brush_colors_flip():
     pass
 
 
-def brush_select(paint_mode: int = 'ACTIVE',
-                 sculpt_tool: int = 'BLOB',
-                 vertex_paint_tool: int = 'MIX',
-                 weight_paint_tool: int = 'MIX',
-                 texture_paint_tool: int = 'DRAW',
+def brush_select(paint_mode: typing.Union[int, str] = 'ACTIVE',
+                 sculpt_tool: typing.Union[int, str] = 'BLOB',
+                 vertex_paint_tool: typing.Union[int, str] = 'MIX',
+                 weight_paint_tool: typing.Union[int, str] = 'MIX',
+                 texture_paint_tool: typing.Union[int, str] = 'DRAW',
                  toggle: bool = False,
                  create_missing: bool = False):
     '''Select a paint mode’s brush by tool type 
 
     :param paint_mode: Paint ModeACTIVE Current, Set brush for active paint mode.SCULPT Sculpt.VERTEX_PAINT Vertex Paint.WEIGHT_PAINT Weight Paint.TEXTURE_PAINT Texture Paint. 
-    :type paint_mode: int
+    :type paint_mode: typing.Union[int, str]
     :param sculpt_tool: Sculpt Tool 
-    :type sculpt_tool: int
+    :type sculpt_tool: typing.Union[int, str]
     :param vertex_paint_tool: Vertex Paint ToolMIX Mix, Use mix blending mode while painting.ADD Add, Use add blending mode while painting.SUB Subtract, Use subtract blending mode while painting.MUL Multiply, Use multiply blending mode while painting.BLUR Blur, Blur the color with surrounding values.LIGHTEN Lighten, Use lighten blending mode while painting.DARKEN Darken, Use darken blending mode while painting. 
-    :type vertex_paint_tool: int
+    :type vertex_paint_tool: typing.Union[int, str]
     :param weight_paint_tool: Weight Paint ToolMIX Mix, Use mix blending mode while painting.ADD Add, Use add blending mode while painting.SUB Subtract, Use subtract blending mode while painting.MUL Multiply, Use multiply blending mode while painting.BLUR Blur, Blur the color with surrounding values.LIGHTEN Lighten, Use lighten blending mode while painting.DARKEN Darken, Use darken blending mode while painting. 
-    :type weight_paint_tool: int
+    :type weight_paint_tool: typing.Union[int, str]
     :param texture_paint_tool: Texture Paint Tool 
-    :type texture_paint_tool: int
+    :type texture_paint_tool: typing.Union[int, str]
     :param toggle: Toggle, Toggle between two brushes rather than cycling 
     :type toggle: bool
     :param create_missing: Create Missing, If the requested brush type does not exist, create a new brush 
@@ -86,11 +85,11 @@ def delete_texture_paint_slot():
     pass
 
 
-def face_select_all(action: int = 'TOGGLE'):
+def face_select_all(action: typing.Union[int, str] = 'TOGGLE'):
     '''Change selection for all faces 
 
     :param action: Action, Selection action to executeTOGGLE Toggle, Toggle selection for all elements.SELECT Select, Select all elements.DESELECT Deselect, Deselect all elements.INVERT Invert, Invert selection of all elements. 
-    :type action: int
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -134,18 +133,18 @@ def face_select_reveal(unselected: bool = False):
     pass
 
 
-def grab_clone(delta: float = (0.0, 0.0)):
+def grab_clone(delta: typing.List[float] = (0.0, 0.0)):
     '''Move the clone source image 
 
     :param delta: Delta, Delta offset of clone image in 0.0..1.0 coordinates 
-    :type delta: float
+    :type delta: typing.List[float]
     '''
 
     pass
 
 
-def hide_show(action: int = 'HIDE',
-              area: int = 'INSIDE',
+def hide_show(action: typing.Union[int, str] = 'HIDE',
+              area: typing.Union[int, str] = 'INSIDE',
               xmin: int = 0,
               xmax: int = 0,
               ymin: int = 0,
@@ -153,9 +152,9 @@ def hide_show(action: int = 'HIDE',
     '''Hide/show some vertices 
 
     :param action: Action, Whether to hide or show verticesHIDE Hide, Hide vertices.SHOW Show, Show vertices. 
-    :type action: int
+    :type action: typing.Union[int, str]
     :param area: Area, Which vertices to hide or showOUTSIDE Outside, Hide or show vertices outside the selection.INSIDE Inside, Hide or show vertices inside the selection.ALL All, Hide or show all vertices.MASKED Masked, Hide or show vertices that are masked (minimum mask value of 0.5). 
-    :type area: int
+    :type area: typing.Union[int, str]
     :param xmin: X Min 
     :type xmin: int
     :param xmax: X Max 
@@ -179,24 +178,27 @@ def image_from_view(filepath: str = ""):
     pass
 
 
-def image_paint(stroke: typing.List['bpy.types.OperatorStrokeElement'] = None,
-                mode: int = 'NORMAL'):
+def image_paint(
+        stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
+                             'bpy_prop_collection'] = None,
+        mode: typing.Union[int, str] = 'NORMAL'):
     '''Paint a stroke into the image 
 
     :param stroke: Stroke 
-    :type stroke: typing.List['bpy.types.OperatorStrokeElement']
+    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param mode: Stroke Mode, Action taken when a paint stroke is madeNORMAL Normal, Apply brush normally.INVERT Invert, Invert action of brush for duration of stroke.SMOOTH Smooth, Switch brush to smooth mode for duration of stroke. 
-    :type mode: int
+    :type mode: typing.Union[int, str]
     '''
 
     pass
 
 
-def mask_flood_fill(mode: int = 'VALUE', value: float = 0.0):
+def mask_flood_fill(mode: typing.Union[int, str] = 'VALUE',
+                    value: float = 0.0):
     '''Fill the whole mask with a given value, or invert its values 
 
     :param mode: ModeVALUE Value, Set mask to the level specified by the ‘value’ property.VALUE_INVERSE Value Inverted, Set mask to the level specified by the inverted ‘value’ property.INVERT Invert, Invert the mask. 
-    :type mode: int
+    :type mode: typing.Union[int, str]
     :param value: Value, Mask level to use when mode is ‘Value’; zero means no masking and one is fully masked 
     :type value: float
     '''
@@ -204,15 +206,17 @@ def mask_flood_fill(mode: int = 'VALUE', value: float = 0.0):
     pass
 
 
-def mask_lasso_gesture(path: typing.List['bpy.types.OperatorMousePath'] = None,
-                       mode: int = 'VALUE',
-                       value: float = 1.0):
+def mask_lasso_gesture(
+        path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
+                           'bpy_prop_collection'] = None,
+        mode: typing.Union[int, str] = 'VALUE',
+        value: float = 1.0):
     '''Add mask within the lasso as you move the brush 
 
     :param path: path 
-    :type path: typing.List['bpy.types.OperatorMousePath']
+    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param mode: ModeVALUE Value, Set mask to the level specified by the ‘value’ property.VALUE_INVERSE Value Inverted, Set mask to the level specified by the inverted ‘value’ property.INVERT Invert, Invert the mask. 
-    :type mode: int
+    :type mode: typing.Union[int, str]
     :param value: Value, Mask level to use when mode is ‘Value’; zero means no masking and one is fully masked 
     :type value: float
     '''
@@ -220,23 +224,23 @@ def mask_lasso_gesture(path: typing.List['bpy.types.OperatorMousePath'] = None,
     pass
 
 
-def project_image(image: int = ''):
+def project_image(image: typing.Union[int, str] = ''):
     '''Project an edited render from the active camera back onto the object 
 
     :param image: Image 
-    :type image: int
+    :type image: typing.Union[int, str]
     '''
 
     pass
 
 
-def sample_color(location: int = (0, 0),
+def sample_color(location: typing.List[int] = (0, 0),
                  merged: bool = False,
                  palette: bool = False):
     '''Use the mouse to sample a color in the image 
 
     :param location: Location 
-    :type location: int
+    :type location: typing.List[int]
     :param merged: Sample Merged, Sample the output display color 
     :type merged: bool
     :param palette: Add to Palette 
@@ -254,11 +258,11 @@ def texture_paint_toggle():
     pass
 
 
-def vert_select_all(action: int = 'TOGGLE'):
+def vert_select_all(action: typing.Union[int, str] = 'TOGGLE'):
     '''Change selection for all vertices 
 
     :param action: Action, Selection action to executeTOGGLE Toggle, Toggle selection for all elements.SELECT Select, Select all elements.DESELECT Deselect, Deselect all elements.INVERT Invert, Invert selection of all elements. 
-    :type action: int
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -359,14 +363,16 @@ def vertex_color_smooth():
     pass
 
 
-def vertex_paint(stroke: typing.List['bpy.types.OperatorStrokeElement'] = None,
-                 mode: int = 'NORMAL'):
+def vertex_paint(
+        stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
+                             'bpy_prop_collection'] = None,
+        mode: typing.Union[int, str] = 'NORMAL'):
     '''Paint a stroke in the active vertex color layer 
 
     :param stroke: Stroke 
-    :type stroke: typing.List['bpy.types.OperatorStrokeElement']
+    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param mode: Stroke Mode, Action taken when a paint stroke is madeNORMAL Normal, Apply brush normally.INVERT Invert, Invert action of brush for duration of stroke.SMOOTH Smooth, Switch brush to smooth mode for duration of stroke. 
-    :type mode: int
+    :type mode: typing.Union[int, str]
     '''
 
     pass
@@ -380,17 +386,17 @@ def vertex_paint_toggle():
     pass
 
 
-def weight_from_bones(type: int = 'AUTOMATIC'):
+def weight_from_bones(type: typing.Union[int, str] = 'AUTOMATIC'):
     '''Set the weights of the groups matching the attached armature’s selected bones, using the distance between the vertices and the bones 
 
     :param type: Type, Method to use for assigning weightsAUTOMATIC Automatic, Automatic weights from bones.ENVELOPES From Envelopes, Weights from envelopes with user defined radius. 
-    :type type: int
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
-def weight_gradient(type: int = 'LINEAR',
+def weight_gradient(type: typing.Union[int, str] = 'LINEAR',
                     xstart: int = 0,
                     xend: int = 0,
                     ystart: int = 0,
@@ -399,7 +405,7 @@ def weight_gradient(type: int = 'LINEAR',
     '''Draw a line to apply a weight gradient to selected vertices 
 
     :param type: Type 
-    :type type: int
+    :type type: typing.Union[int, str]
     :param xstart: X Start 
     :type xstart: int
     :param xend: X End 
@@ -415,14 +421,16 @@ def weight_gradient(type: int = 'LINEAR',
     pass
 
 
-def weight_paint(stroke: typing.List['bpy.types.OperatorStrokeElement'] = None,
-                 mode: int = 'NORMAL'):
+def weight_paint(
+        stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
+                             'bpy_prop_collection'] = None,
+        mode: typing.Union[int, str] = 'NORMAL'):
     '''Paint a stroke in the current vertex group’s weights 
 
     :param stroke: Stroke 
-    :type stroke: typing.List['bpy.types.OperatorStrokeElement']
+    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param mode: Stroke Mode, Action taken when a paint stroke is madeNORMAL Normal, Apply brush normally.INVERT Invert, Invert action of brush for duration of stroke.SMOOTH Smooth, Switch brush to smooth mode for duration of stroke. 
-    :type mode: int
+    :type mode: typing.Union[int, str]
     '''
 
     pass
@@ -444,11 +452,11 @@ def weight_sample():
     pass
 
 
-def weight_sample_group(group: int = 'DEFAULT'):
+def weight_sample_group(group: typing.Union[int, str] = 'DEFAULT'):
     '''Select one of the vertex groups available under current mouse position 
 
     :param group: Keying Set, The Keying Set to use 
-    :type group: int
+    :type group: typing.Union[int, str]
     '''
 
     pass
