@@ -1,13 +1,14 @@
 import sys
 import typing
-import bpy
 
 
-def brush_edit(stroke: typing.List['bpy.types.OperatorStrokeElement'] = None):
+def brush_edit(
+        stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
+                             'bpy_prop_collection'] = None):
     '''Apply a stroke of brush to the particles 
 
     :param stroke: Stroke 
-    :type stroke: typing.List['bpy.types.OperatorStrokeElement']
+    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     '''
 
     pass
@@ -23,13 +24,13 @@ def connect_hair(all: bool = False):
     pass
 
 
-def copy_particle_systems(space: int = 'OBJECT',
+def copy_particle_systems(space: typing.Union[int, str] = 'OBJECT',
                           remove_target_particles: bool = True,
                           use_active: bool = False):
     '''Copy particle systems from the active object to selected objects 
 
     :param space: Space, Space transform for copying from one object to anotherOBJECT Object, Copy inside each object’s local space.WORLD World, Copy in world space. 
-    :type space: int
+    :type space: typing.Union[int, str]
     :param remove_target_particles: Remove Target Particles, Remove particle systems on the target objects 
     :type remove_target_particles: bool
     :param use_active: Use Active, Use the active particle system from the context 
@@ -39,11 +40,11 @@ def copy_particle_systems(space: int = 'OBJECT',
     pass
 
 
-def delete(type: int = 'PARTICLE'):
+def delete(type: typing.Union[int, str] = 'PARTICLE'):
     '''Delete selected particles or keys 
 
     :param type: Type, Delete a full particle or only keys 
-    :type type: int
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -181,11 +182,11 @@ def reveal():
     pass
 
 
-def select_all(action: int = 'TOGGLE'):
+def select_all(action: typing.Union[int, str] = 'TOGGLE'):
     '''(De)select all particles’ keys 
 
     :param action: Action, Selection action to executeTOGGLE Toggle, Toggle selection for all elements.SELECT Select, Select all elements.DESELECT Deselect, Deselect all elements.INVERT Invert, Invert selection of all elements. 
-    :type action: int
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -199,13 +200,13 @@ def select_less():
     pass
 
 
-def select_linked(deselect: bool = False, location: int = (0, 0)):
+def select_linked(deselect: bool = False, location: typing.List[int] = (0, 0)):
     '''Select nearest particle from mouse pointer 
 
     :param deselect: Deselect, Deselect linked keys rather than selecting them 
     :type deselect: bool
     :param location: Location 
-    :type location: int
+    :type location: typing.List[int]
     '''
 
     pass
@@ -221,8 +222,8 @@ def select_more():
 
 def select_random(percent: float = 50.0,
                   seed: int = 0,
-                  action: int = 'SELECT',
-                  type: int = 'HAIR'):
+                  action: typing.Union[int, str] = 'SELECT',
+                  type: typing.Union[int, str] = 'HAIR'):
     '''Select a randomly distributed set of hair or points 
 
     :param percent: Percent, Percentage of objects to select randomly 
@@ -230,29 +231,29 @@ def select_random(percent: float = 50.0,
     :param seed: Random Seed, Seed for the random number generator 
     :type seed: int
     :param action: Action, Selection action to executeSELECT Select, Select all elements.DESELECT Deselect, Deselect all elements. 
-    :type action: int
+    :type action: typing.Union[int, str]
     :param type: Type, Select either hair or points 
-    :type type: int
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
-def select_roots(action: int = 'SELECT'):
+def select_roots(action: typing.Union[int, str] = 'SELECT'):
     '''Select roots of all visible particles 
 
     :param action: Action, Selection action to executeTOGGLE Toggle, Toggle selection for all elements.SELECT Select, Select all elements.DESELECT Deselect, Deselect all elements.INVERT Invert, Invert selection of all elements. 
-    :type action: int
+    :type action: typing.Union[int, str]
     '''
 
     pass
 
 
-def select_tips(action: int = 'SELECT'):
+def select_tips(action: typing.Union[int, str] = 'SELECT'):
     '''Select tips of all visible particles 
 
     :param action: Action, Selection action to executeTOGGLE Toggle, Toggle selection for all elements.SELECT Select, Select all elements.DESELECT Deselect, Deselect all elements.INVERT Invert, Invert selection of all elements. 
-    :type action: int
+    :type action: typing.Union[int, str]
     '''
 
     pass
