@@ -50,23 +50,23 @@ def pose_add(frame: int = 1, name: str = "Pose"):
     pass
 
 
-def pose_remove(pose: int = ''):
+def pose_remove(pose: typing.Union[int, str] = ''):
     '''Remove nth pose from the active Pose Library 
 
     :param pose: Pose, The pose to remove 
-    :type pose: int
+    :type pose: typing.Union[int, str]
     '''
 
     pass
 
 
-def pose_rename(name: str = "RenamedPose", pose: int = ''):
+def pose_rename(name: str = "RenamedPose", pose: typing.Union[int, str] = ''):
     '''Rename specified pose from the active Pose Library 
 
     :param name: New Pose Name, New name for pose 
     :type name: str
     :param pose: Pose, The pose to rename 
-    :type pose: int
+    :type pose: typing.Union[int, str]
     '''
 
     pass
