@@ -26,31 +26,34 @@ def freestyle_add_face_marks_to_keying_set():
     pass
 
 
-def freestyle_alpha_modifier_add(type: int = 'ALONG_STROKE'):
+def freestyle_alpha_modifier_add(
+        type: typing.Union[int, str] = 'ALONG_STROKE'):
     '''Add an alpha transparency modifier to the line style associated with the active lineset 
 
     :param type: Type 
-    :type type: int
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
-def freestyle_color_modifier_add(type: int = 'ALONG_STROKE'):
+def freestyle_color_modifier_add(
+        type: typing.Union[int, str] = 'ALONG_STROKE'):
     '''Add a line color modifier to the line style associated with the active lineset 
 
     :param type: Type 
-    :type type: int
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
-def freestyle_fill_range_by_selection(type: int = 'COLOR', name: str = ""):
+def freestyle_fill_range_by_selection(type: typing.Union[int, str] = 'COLOR',
+                                      name: str = ""):
     '''Fill the Range Min/Max entries by the min/max distance between selected mesh objects and the source object 
 
     :param type: Type, Type of the modifier to work onCOLOR Color, Color modifier type.ALPHA Alpha, Alpha modifier type.THICKNESS Thickness, Thickness modifier type. 
-    :type type: int
+    :type type: typing.Union[int, str]
     :param name: Name, Name of the modifier to work on 
     :type name: str
     '''
@@ -58,11 +61,12 @@ def freestyle_fill_range_by_selection(type: int = 'COLOR', name: str = ""):
     pass
 
 
-def freestyle_geometry_modifier_add(type: int = '2D_OFFSET'):
+def freestyle_geometry_modifier_add(
+        type: typing.Union[int, str] = '2D_OFFSET'):
     '''Add a stroke geometry modifier to the line style associated with the active lineset 
 
     :param type: Type 
-    :type type: int
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -84,11 +88,11 @@ def freestyle_lineset_copy():
     pass
 
 
-def freestyle_lineset_move(direction: int = 'UP'):
+def freestyle_lineset_move(direction: typing.Union[int, str] = 'UP'):
     '''Change the position of the active line set within the list of line sets 
 
     :param direction: Direction, Direction to move, UP or DOWN 
-    :type direction: int
+    :type direction: typing.Union[int, str]
     '''
 
     pass
@@ -126,11 +130,11 @@ def freestyle_modifier_copy():
     pass
 
 
-def freestyle_modifier_move(direction: int = 'UP'):
+def freestyle_modifier_move(direction: typing.Union[int, str] = 'UP'):
     '''Move the modifier within the list of modifiers 
 
     :param direction: Direction, Direction to move, UP or DOWN 
-    :type direction: int
+    :type direction: typing.Union[int, str]
     '''
 
     pass
@@ -152,11 +156,11 @@ def freestyle_module_add():
     pass
 
 
-def freestyle_module_move(direction: int = 'UP'):
+def freestyle_module_move(direction: typing.Union[int, str] = 'UP'):
     '''Change the position of the style module within in the list of style modules 
 
     :param direction: Direction, Direction to move, UP or DOWN 
-    :type direction: int
+    :type direction: typing.Union[int, str]
     '''
 
     pass
@@ -190,21 +194,22 @@ def freestyle_stroke_material_create():
     pass
 
 
-def freestyle_thickness_modifier_add(type: int = 'ALONG_STROKE'):
+def freestyle_thickness_modifier_add(
+        type: typing.Union[int, str] = 'ALONG_STROKE'):
     '''Add a line thickness modifier to the line style associated with the active lineset 
 
     :param type: Type 
-    :type type: int
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
-def new(type: int = 'NEW'):
+def new(type: typing.Union[int, str] = 'NEW'):
     '''Add new scene by type 
 
     :param type: TypeNEW New, Add new scene.EMPTY Copy Settings, Make a copy without any objects.LINK_OBJECTS Link Objects, Link to the objects from the current scene.LINK_OBJECT_DATA Link Object Data, Copy objects linked to data from the current scene.FULL_COPY Full Copy, Make a full copy of the current scene. 
-    :type type: int
+    :type type: typing.Union[int, str]
     '''
 
     pass
