@@ -27,12 +27,12 @@ def mixdown(filepath: str = "",
             filter_blenlib: bool = False,
             filemode: int = 9,
             relative_path: bool = True,
-            display_type: int = 'DEFAULT',
-            sort_method: int = 'FILE_SORT_ALPHA',
+            display_type: typing.Union[int, str] = 'DEFAULT',
+            sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
             accuracy: int = 1024,
-            container: int = 'FLAC',
-            codec: int = 'FLAC',
-            format: int = 'S16',
+            container: typing.Union[int, str] = 'FLAC',
+            codec: typing.Union[int, str] = 'FLAC',
+            format: typing.Union[int, str] = 'S16',
             bitrate: int = 192,
             split_channels: bool = False):
     '''Mixes the scene’s audio to a sound file 
@@ -72,17 +72,17 @@ def mixdown(filepath: str = "",
     :param relative_path: Relative Path, Select the file relative to the blend file 
     :type relative_path: bool
     :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
-    :type display_type: int
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
-    :type sort_method: int
+    :type sort_method: typing.Union[int, str]
     :param accuracy: Accuracy, Sample accuracy, important for animation data (the lower the value, the more accurate) 
     :type accuracy: int
     :param container: Container, File formatAC3 ac3, Dolby Digital ATRAC 3.FLAC flac, Free Lossless Audio Codec.MATROSKA mkv, Matroska.MP2 mp2, MPEG-1 Audio Layer II.MP3 mp3, MPEG-2 Audio Layer III.OGG ogg, Xiph.Org Ogg Container.WAV wav, Waveform Audio File Format. 
-    :type container: int
+    :type container: typing.Union[int, str]
     :param codec: Codec, Audio CodecAAC AAC, Advanced Audio Coding.AC3 AC3, Dolby Digital ATRAC 3.FLAC FLAC, Free Lossless Audio Codec.MP2 MP2, MPEG-1 Audio Layer II.MP3 MP3, MPEG-2 Audio Layer III.PCM PCM, Pulse Code Modulation (RAW).VORBIS Vorbis, Xiph.Org Vorbis Codec. 
-    :type codec: int
+    :type codec: typing.Union[int, str]
     :param format: Format, Sample formatU8 U8, 8 bit unsigned.S16 S16, 16 bit signed.S24 S24, 24 bit signed.S32 S32, 32 bit signed.F32 F32, 32 bit floating point.F64 F64, 64 bit floating point. 
-    :type format: int
+    :type format: typing.Union[int, str]
     :param bitrate: Bitrate, Bitrate in kbit/s 
     :type bitrate: int
     :param split_channels: Split channels, Each channel will be rendered into a mono file 
@@ -110,8 +110,8 @@ def open(filepath: str = "",
          relative_path: bool = True,
          show_multiview: bool = False,
          use_multiview: bool = False,
-         display_type: int = 'DEFAULT',
-         sort_method: int = 'FILE_SORT_ALPHA',
+         display_type: typing.Union[int, str] = 'DEFAULT',
+         sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
          cache: bool = False,
          mono: bool = False):
     '''Load a sound file 
@@ -153,9 +153,9 @@ def open(filepath: str = "",
     :param use_multiview: Use Multi-View 
     :type use_multiview: bool
     :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
-    :type display_type: int
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
-    :type sort_method: int
+    :type sort_method: typing.Union[int, str]
     :param cache: Cache, Cache the sound in memory 
     :type cache: bool
     :param mono: Mono, Merge all the sound’s channels into one 
@@ -183,8 +183,8 @@ def open_mono(filepath: str = "",
               relative_path: bool = True,
               show_multiview: bool = False,
               use_multiview: bool = False,
-              display_type: int = 'DEFAULT',
-              sort_method: int = 'FILE_SORT_ALPHA',
+              display_type: typing.Union[int, str] = 'DEFAULT',
+              sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
               cache: bool = False,
               mono: bool = True):
     '''Load a sound file as mono 
@@ -226,9 +226,9 @@ def open_mono(filepath: str = "",
     :param use_multiview: Use Multi-View 
     :type use_multiview: bool
     :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
-    :type display_type: int
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
-    :type sort_method: int
+    :type sort_method: typing.Union[int, str]
     :param cache: Cache, Cache the sound in memory 
     :type cache: bool
     :param mono: Mono, Mixdown the sound to mono 
@@ -246,11 +246,11 @@ def pack():
     pass
 
 
-def unpack(method: int = 'USE_LOCAL', id: str = ""):
+def unpack(method: typing.Union[int, str] = 'USE_LOCAL', id: str = ""):
     '''Unpack the sound to the samples filename 
 
     :param method: Method, How to unpack 
-    :type method: int
+    :type method: typing.Union[int, str]
     :param id: Sound Name, Sound datablock name to unpack 
     :type id: str
     '''
