@@ -1,6 +1,5 @@
 import sys
 import typing
-import bpy
 
 
 def addon_disable(module: str = ""):
@@ -34,7 +33,7 @@ def addon_expand(module: str = ""):
 
 
 def addon_install(overwrite: bool = True,
-                  target: int = 'DEFAULT',
+                  target: typing.Union[int, str] = 'DEFAULT',
                   filepath: str = "",
                   filter_folder: bool = True,
                   filter_python: bool = True,
@@ -44,7 +43,7 @@ def addon_install(overwrite: bool = True,
     :param overwrite: Overwrite, Remove existing add-ons with the same ID 
     :type overwrite: bool
     :param target: Target Path 
-    :type target: int
+    :type target: typing.Union[int, str]
     :param filepath: filepath 
     :type filepath: str
     :param filter_folder: Filter folders 
@@ -76,6 +75,16 @@ def addon_remove(module: str = ""):
     pass
 
 
+def addon_userpref_show(module: str = ""):
+    '''Show add-on user preferences 
+
+    :param module: Module, Module name of the add-on to expand 
+    :type module: str
+    '''
+
+    pass
+
+
 def alembic_export(filepath: str = "",
                    check_existing: bool = True,
                    filter_blender: bool = False,
@@ -92,8 +101,8 @@ def alembic_export(filepath: str = "",
                    filter_folder: bool = True,
                    filter_blenlib: bool = False,
                    filemode: int = 8,
-                   display_type: int = 'DEFAULT',
-                   sort_method: int = 'FILE_SORT_ALPHA',
+                   display_type: typing.Union[int, str] = 'DEFAULT',
+                   sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
                    start: int = 1,
                    end: int = 1,
                    xsamples: int = 1,
@@ -111,7 +120,7 @@ def alembic_export(filepath: str = "",
                    face_sets: bool = False,
                    subdiv_schema: bool = False,
                    apply_subdiv: bool = False,
-                   compression_type: int = 'OGAWA',
+                   compression_type: typing.Union[int, str] = 'OGAWA',
                    global_scale: float = 1.0):
     '''Export current scene in an Alembic archive 
 
@@ -148,9 +157,9 @@ def alembic_export(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
     :type filemode: int
     :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
-    :type display_type: int
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
-    :type sort_method: int
+    :type sort_method: typing.Union[int, str]
     :param start: Start Frame, Start Frame 
     :type start: int
     :param end: End Frame, End Frame 
@@ -186,7 +195,7 @@ def alembic_export(filepath: str = "",
     :param apply_subdiv: Apply Subsurf, Export subdivision surfaces as meshes 
     :type apply_subdiv: bool
     :param compression_type: Compression 
-    :type compression_type: int
+    :type compression_type: typing.Union[int, str]
     :param global_scale: Scale, Value by which to enlarge or shrink the objects with respect to the world’s origin 
     :type global_scale: float
     '''
@@ -210,8 +219,8 @@ def alembic_import(filepath: str = "",
                    filter_folder: bool = True,
                    filter_blenlib: bool = False,
                    filemode: int = 8,
-                   display_type: int = 'DEFAULT',
-                   sort_method: int = 'FILE_SORT_ALPHA',
+                   display_type: typing.Union[int, str] = 'DEFAULT',
+                   sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
                    scale: float = 1.0,
                    set_frame_range: bool = True,
                    validate_meshes: bool = False,
@@ -251,9 +260,9 @@ def alembic_import(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
     :type filemode: int
     :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
-    :type display_type: int
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
-    :type sort_method: int
+    :type sort_method: typing.Union[int, str]
     :param scale: Scale, Value by which to enlarge or shrink the objects with respect to the world’s origin 
     :type scale: float
     :param set_frame_range: Set Frame Range, If checked, update scene’s start and end frame to match those of the Alembic archive 
@@ -285,32 +294,34 @@ def appconfig_default():
     pass
 
 
-def append(filepath: str = "",
-           directory: str = "",
-           filename: str = "",
-           files: typing.List['bpy.types.OperatorFileListElement'] = None,
-           filter_blender: bool = True,
-           filter_backup: bool = False,
-           filter_image: bool = False,
-           filter_movie: bool = False,
-           filter_python: bool = False,
-           filter_font: bool = False,
-           filter_sound: bool = False,
-           filter_text: bool = False,
-           filter_btx: bool = False,
-           filter_collada: bool = False,
-           filter_alembic: bool = False,
-           filter_folder: bool = True,
-           filter_blenlib: bool = True,
-           filemode: int = 1,
-           display_type: int = 'DEFAULT',
-           sort_method: int = 'FILE_SORT_ALPHA',
-           link: bool = False,
-           autoselect: bool = True,
-           active_layer: bool = True,
-           instance_groups: bool = False,
-           set_fake: bool = False,
-           use_recursive: bool = True):
+def append(
+        filepath: str = "",
+        directory: str = "",
+        filename: str = "",
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
+        filter_blender: bool = True,
+        filter_backup: bool = False,
+        filter_image: bool = False,
+        filter_movie: bool = False,
+        filter_python: bool = False,
+        filter_font: bool = False,
+        filter_sound: bool = False,
+        filter_text: bool = False,
+        filter_btx: bool = False,
+        filter_collada: bool = False,
+        filter_alembic: bool = False,
+        filter_folder: bool = True,
+        filter_blenlib: bool = True,
+        filemode: int = 1,
+        display_type: typing.Union[int, str] = 'DEFAULT',
+        sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
+        link: bool = False,
+        autoselect: bool = True,
+        active_layer: bool = True,
+        instance_groups: bool = False,
+        set_fake: bool = False,
+        use_recursive: bool = True):
     '''Append from a Library .blend file 
 
     :param filepath: File Path, Path to file 
@@ -320,7 +331,7 @@ def append(filepath: str = "",
     :param filename: File Name, Name of the file 
     :type filename: str
     :param files: Files 
-    :type files: typing.List['bpy.types.OperatorFileListElement']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files 
     :type filter_blender: bool
     :param filter_backup: Filter .blend files 
@@ -350,9 +361,9 @@ def append(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
     :type filemode: int
     :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
-    :type display_type: int
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
-    :type sort_method: int
+    :type sort_method: typing.Union[int, str]
     :param link: Link, Link the objects or datablocks rather than appending 
     :type link: bool
     :param autoselect: Select, Select new objects 
@@ -414,11 +425,11 @@ def collada_export(filepath: str = "",
                    filter_folder: bool = True,
                    filter_blenlib: bool = False,
                    filemode: int = 8,
-                   display_type: int = 'DEFAULT',
-                   sort_method: int = 'FILE_SORT_ALPHA',
+                   display_type: typing.Union[int, str] = 'DEFAULT',
+                   sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
                    apply_modifiers: bool = False,
                    export_mesh_type: int = 0,
-                   export_mesh_type_selection: int = 'view',
+                   export_mesh_type_selection: typing.Union[int, str] = 'view',
                    selected: bool = False,
                    include_children: bool = False,
                    include_armatures: bool = False,
@@ -433,7 +444,8 @@ def collada_export(filepath: str = "",
                    use_blender_profile: bool = True,
                    sort_by_name: bool = False,
                    export_transformation_type: int = 0,
-                   export_transformation_type_selection: int = 'matrix',
+                   export_transformation_type_selection: typing.
+                   Union[int, str] = 'matrix',
                    open_sim: bool = False):
     '''Save a Collada file 
 
@@ -470,15 +482,15 @@ def collada_export(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
     :type filemode: int
     :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
-    :type display_type: int
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
-    :type sort_method: int
+    :type sort_method: typing.Union[int, str]
     :param apply_modifiers: Apply Modifiers, Apply modifiers to exported mesh (non destructive)) 
     :type apply_modifiers: bool
     :param export_mesh_type: Resolution, Modifier resolution for export 
     :type export_mesh_type: int
     :param export_mesh_type_selection: Resolution, Modifier resolution for exportview View, Apply modifier’s view settings.render Render, Apply modifier’s render settings. 
-    :type export_mesh_type_selection: int
+    :type export_mesh_type_selection: typing.Union[int, str]
     :param selected: Selection Only, Export only selected elements 
     :type selected: bool
     :param include_children: Include Children, Export all children of selected objects (even if not selected) 
@@ -508,7 +520,7 @@ def collada_export(filepath: str = "",
     :param export_transformation_type: Transform, Transformation type for translation, scale and rotation 
     :type export_transformation_type: int
     :param export_transformation_type_selection: Transform, Transformation type for translation, scale and rotationmatrix Matrix, Use <matrix> to specify transformations.transrotloc TransRotLoc, Use <translate>, <rotate>, <scale> to specify transformations.both Both, Use <matrix> AND <translate>, <rotate>, <scale> to specify transformations. 
-    :type export_transformation_type_selection: int
+    :type export_transformation_type_selection: typing.Union[int, str]
     :param open_sim: Export to SL/OpenSim, Compatibility mode for SL, OpenSim and other compatible online worlds 
     :type open_sim: bool
     '''
@@ -531,8 +543,8 @@ def collada_import(filepath: str = "",
                    filter_folder: bool = True,
                    filter_blenlib: bool = False,
                    filemode: int = 8,
-                   display_type: int = 'DEFAULT',
-                   sort_method: int = 'FILE_SORT_ALPHA',
+                   display_type: typing.Union[int, str] = 'DEFAULT',
+                   sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
                    import_units: bool = False,
                    fix_orientation: bool = False,
                    find_chains: bool = False,
@@ -571,9 +583,9 @@ def collada_import(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
     :type filemode: int
     :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
-    :type display_type: int
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
-    :type sort_method: int
+    :type sort_method: typing.Union[int, str]
     :param import_units: Import Units, If disabled match import to Blender’s current Unit settings, otherwise use the settings from the Imported scene 
     :type import_units: bool
     :param fix_orientation: Fix Leaf Bones, Fix Orientation of Leaf Bones (Collada does only support Joints) 
@@ -591,7 +603,7 @@ def collada_import(filepath: str = "",
 
 def context_collection_boolean_set(data_path_iter: str = "",
                                    data_path_item: str = "",
-                                   type: int = 'TOGGLE'):
+                                   type: typing.Union[int, str] = 'TOGGLE'):
     '''Set boolean values for a collection of items 
 
     :param data_path_iter: data_path_iter, The data path relative to the context, must point to an iterable 
@@ -599,7 +611,7 @@ def context_collection_boolean_set(data_path_iter: str = "",
     :param data_path_item: data_path_item, The data path from each iterable to the value (int or float) 
     :type data_path_item: str
     :param type: Type 
-    :type type: int
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -1054,8 +1066,8 @@ def lib_reload(library: str = "",
                filter_blenlib: bool = False,
                filemode: int = 8,
                relative_path: bool = True,
-               display_type: int = 'DEFAULT',
-               sort_method: int = 'FILE_SORT_ALPHA'):
+               display_type: typing.Union[int, str] = 'DEFAULT',
+               sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
     '''Reload the given library 
 
     :param library: Library, Library to reload 
@@ -1097,9 +1109,9 @@ def lib_reload(library: str = "",
     :param relative_path: Relative Path, Select the file relative to the blend file 
     :type relative_path: bool
     :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
-    :type display_type: int
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
-    :type sort_method: int
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
@@ -1110,7 +1122,8 @@ def lib_relocate(
         filepath: str = "",
         directory: str = "",
         filename: str = "",
-        files: typing.List['bpy.types.OperatorFileListElement'] = None,
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
         filter_blender: bool = True,
         filter_backup: bool = False,
         filter_image: bool = False,
@@ -1126,8 +1139,8 @@ def lib_relocate(
         filter_blenlib: bool = False,
         filemode: int = 8,
         relative_path: bool = True,
-        display_type: int = 'DEFAULT',
-        sort_method: int = 'FILE_SORT_ALPHA'):
+        display_type: typing.Union[int, str] = 'DEFAULT',
+        sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
     '''Relocate the given library to one or several others 
 
     :param library: Library, Library to relocate 
@@ -1139,7 +1152,7 @@ def lib_relocate(
     :param filename: File Name, Name of the file 
     :type filename: str
     :param files: Files 
-    :type files: typing.List['bpy.types.OperatorFileListElement']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files 
     :type filter_blender: bool
     :param filter_backup: Filter .blend files 
@@ -1171,9 +1184,9 @@ def lib_relocate(
     :param relative_path: Relative Path, Select the file relative to the blend file 
     :type relative_path: bool
     :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
-    :type display_type: int
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
-    :type sort_method: int
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
@@ -1182,7 +1195,8 @@ def lib_relocate(
 def link(filepath: str = "",
          directory: str = "",
          filename: str = "",
-         files: typing.List['bpy.types.OperatorFileListElement'] = None,
+         files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                             'bpy_prop_collection'] = None,
          filter_blender: bool = True,
          filter_backup: bool = False,
          filter_image: bool = False,
@@ -1198,8 +1212,8 @@ def link(filepath: str = "",
          filter_blenlib: bool = True,
          filemode: int = 1,
          relative_path: bool = True,
-         display_type: int = 'DEFAULT',
-         sort_method: int = 'FILE_SORT_ALPHA',
+         display_type: typing.Union[int, str] = 'DEFAULT',
+         sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
          link: bool = True,
          autoselect: bool = True,
          active_layer: bool = True,
@@ -1213,7 +1227,7 @@ def link(filepath: str = "",
     :param filename: File Name, Name of the file 
     :type filename: str
     :param files: Files 
-    :type files: typing.List['bpy.types.OperatorFileListElement']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files 
     :type filter_blender: bool
     :param filter_backup: Filter .blend files 
@@ -1245,9 +1259,9 @@ def link(filepath: str = "",
     :param relative_path: Relative Path, Select the file relative to the blend file 
     :type relative_path: bool
     :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
-    :type display_type: int
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
-    :type sort_method: int
+    :type sort_method: typing.Union[int, str]
     :param link: Link, Link the objects or datablocks rather than appending 
     :type link: bool
     :param autoselect: Select, Select new objects 
@@ -1284,8 +1298,8 @@ def open_mainfile(filepath: str = "",
                   filter_folder: bool = True,
                   filter_blenlib: bool = False,
                   filemode: int = 8,
-                  display_type: int = 'DEFAULT',
-                  sort_method: int = 'FILE_SORT_ALPHA',
+                  display_type: typing.Union[int, str] = 'DEFAULT',
+                  sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
                   load_ui: bool = True,
                   use_scripts: bool = True):
     '''Open a Blender file 
@@ -1321,9 +1335,9 @@ def open_mainfile(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
     :type filemode: int
     :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
-    :type display_type: int
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
-    :type sort_method: int
+    :type sort_method: typing.Union[int, str]
     :param load_ui: Load UI, Load user interface setup in the .blend file 
     :type load_ui: bool
     :param use_scripts: Trusted Source, Allow .blend file to execute scripts automatically, default available from system preferences 
@@ -1388,7 +1402,8 @@ def path_open(filepath: str = ""):
 
 
 def previews_batch_clear(
-        files: typing.List['bpy.types.OperatorFileListElement'] = None,
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
         directory: str = "",
         filter_blender: bool = True,
         filter_folder: bool = True,
@@ -1401,7 +1416,7 @@ def previews_batch_clear(
     '''Clear selected .blend file’s previews 
 
     :param files: files 
-    :type files: typing.List['bpy.types.OperatorFileListElement']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param directory: directory 
     :type directory: str
     :param filter_blender: filter_blender 
@@ -1426,7 +1441,8 @@ def previews_batch_clear(
 
 
 def previews_batch_generate(
-        files: typing.List['bpy.types.OperatorFileListElement'] = None,
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
         directory: str = "",
         filter_blender: bool = True,
         filter_folder: bool = True,
@@ -1439,7 +1455,7 @@ def previews_batch_generate(
     '''Generate selected .blend file’s previews 
 
     :param files: files 
-    :type files: typing.List['bpy.types.OperatorFileListElement']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param directory: directory 
     :type directory: str
     :param filter_blender: filter_blender 
@@ -1463,14 +1479,14 @@ def previews_batch_generate(
     pass
 
 
-def previews_clear(id_type: typing.Set[int] = {
+def previews_clear(id_type: typing.Union[typing.Set[int], typing.Set[str]] = {
         'GROUP', 'IMAGE', 'LAMP', 'MATERIAL', 'OBJECT', 'SCENE', 'TEXTURE',
         'WORLD'
 }):
     '''Clear datablock previews (only for some types like objects, materials, textures, etc.) 
 
     :param id_type: DataBlock Type, Which datablock previews to clear 
-    :type id_type: typing.Set[int]
+    :type id_type: typing.Union[typing.Set[int], typing.Set[str]]
     '''
 
     pass
@@ -1641,8 +1657,8 @@ def recover_auto_save(filepath: str = "",
                       filter_folder: bool = False,
                       filter_blenlib: bool = False,
                       filemode: int = 8,
-                      display_type: int = 'LIST_LONG',
-                      sort_method: int = 'FILE_SORT_TIME'):
+                      display_type: typing.Union[int, str] = 'LIST_LONG',
+                      sort_method: typing.Union[int, str] = 'FILE_SORT_TIME'):
     '''Open an automatically saved file to recover it 
 
     :param filepath: File Path, Path to file 
@@ -1676,9 +1692,9 @@ def recover_auto_save(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
     :type filemode: int
     :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
-    :type display_type: int
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
-    :type sort_method: int
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
@@ -1692,13 +1708,13 @@ def recover_last_session():
     pass
 
 
-def redraw_timer(type: int = 'DRAW',
+def redraw_timer(type: typing.Union[int, str] = 'DRAW',
                  iterations: int = 10,
                  time_limit: float = 0.0):
     '''Simple redraw timer to test the speed of updating the interface 
 
     :param type: TypeDRAW Draw Region, Draw Region.DRAW_SWAP Draw Region + Swap, Draw Region and Swap.DRAW_WIN Draw Window, Draw Window.DRAW_WIN_SWAP Draw Window + Swap, Draw Window and Swap.ANIM_STEP Anim Step, Animation Steps.ANIM_PLAY Anim Play, Animation Playback.UNDO Undo/Redo, Undo/Redo. 
-    :type type: int
+    :type type: typing.Union[int, str]
     :param iterations: Iterations, Number of times to redraw 
     :type iterations: int
     :param time_limit: Time Limit, Seconds to run the test for (override iterations) 
@@ -1734,8 +1750,8 @@ def save_as_mainfile(filepath: str = "",
                      filter_folder: bool = True,
                      filter_blenlib: bool = False,
                      filemode: int = 8,
-                     display_type: int = 'DEFAULT',
-                     sort_method: int = 'FILE_SORT_ALPHA',
+                     display_type: typing.Union[int, str] = 'DEFAULT',
+                     sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
                      compress: bool = False,
                      relative_remap: bool = True,
                      copy: bool = False,
@@ -1775,9 +1791,9 @@ def save_as_mainfile(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
     :type filemode: int
     :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
-    :type display_type: int
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
-    :type sort_method: int
+    :type sort_method: typing.Union[int, str]
     :param compress: Compress, Write compressed .blend file 
     :type compress: bool
     :param relative_remap: Remap Relative, Remap relative paths when saving in a different directory 
@@ -1815,8 +1831,8 @@ def save_mainfile(filepath: str = "",
                   filter_folder: bool = True,
                   filter_blenlib: bool = False,
                   filemode: int = 8,
-                  display_type: int = 'DEFAULT',
-                  sort_method: int = 'FILE_SORT_ALPHA',
+                  display_type: typing.Union[int, str] = 'DEFAULT',
+                  sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
                   compress: bool = False,
                   relative_remap: bool = False):
     '''Save the current Blender file 
@@ -1854,9 +1870,9 @@ def save_mainfile(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
     :type filemode: int
     :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
-    :type display_type: int
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
-    :type sort_method: int
+    :type sort_method: typing.Union[int, str]
     :param compress: Compress, Write compressed .blend file 
     :type compress: bool
     :param relative_remap: Remap Relative, Remap relative paths when saving in a different directory 
@@ -1882,19 +1898,19 @@ def search_menu():
     pass
 
 
-def set_stereo_3d(display_mode: int = 'ANAGLYPH',
-                  anaglyph_type: int = 'RED_CYAN',
-                  interlace_type: int = 'ROW_INTERLEAVED',
+def set_stereo_3d(display_mode: typing.Union[int, str] = 'ANAGLYPH',
+                  anaglyph_type: typing.Union[int, str] = 'RED_CYAN',
+                  interlace_type: typing.Union[int, str] = 'ROW_INTERLEAVED',
                   use_interlace_swap: bool = False,
                   use_sidebyside_crosseyed: bool = False):
     '''Toggle 3D stereo support for current window (or change the display mode) 
 
     :param display_mode: Display ModeANAGLYPH Anaglyph, Render views for left and right eyes as two differently filtered colors in a single image (anaglyph glasses are required).INTERLACE Interlace, Render views for left and right eyes interlaced in a single image (3D-ready monitor is required).TIMESEQUENTIAL Time Sequential, Render alternate eyes (also known as page flip, quad buffer support in the graphic card is required).SIDEBYSIDE Side-by-Side, Render views for left and right eyes side-by-side.TOPBOTTOM Top-Bottom, Render views for left and right eyes one above another. 
-    :type display_mode: int
+    :type display_mode: typing.Union[int, str]
     :param anaglyph_type: Anaglyph Type 
-    :type anaglyph_type: int
+    :type anaglyph_type: typing.Union[int, str]
     :param interlace_type: Interlace Type 
-    :type interlace_type: int
+    :type interlace_type: typing.Union[int, str]
     :param use_interlace_swap: Swap Left/Right, Swap left and right stereo channels 
     :type use_interlace_swap: bool
     :param use_sidebyside_crosseyed: Cross-Eyed, Right eye should see left image and vice-versa 
