@@ -1,18 +1,17 @@
 import sys
 import typing
-import bpy
 
 
 class ImagePreviewCollection:
     '''This is a subclass of Python’s built-in dict type, used to store multiple image previews. '''
 
-    def clear(self):
+    def clear(self, ):
         '''Clear all previews. 
 
         '''
         pass
 
-    def close(self):
+    def close(self, ):
         '''Close the collection and clear all previews. 
 
         '''
