@@ -1,6 +1,5 @@
 import sys
 import typing
-import mathutils
 
 
 def area_tri(v1: 'mathutils.Vector', v2: 'mathutils.Vector',
@@ -52,7 +51,7 @@ def box_fit_2d(points: list) -> float:
     pass
 
 
-def box_pack_2d(boxes: list):
+def box_pack_2d(boxes: list) -> tuple:
     '''Returns the normal of the 3D tri or quad. 
 
     :param boxes: list of boxes, each box is a list where the first 4 items are [x, y, width, height, …] other items are ignored. 
@@ -112,7 +111,8 @@ def interpolate_bezier(knot1: 'mathutils.Vector', handle1: 'mathutils.Vector',
 
 
 def intersect_line_line(v1: 'mathutils.Vector', v2: 'mathutils.Vector',
-                        v3: 'mathutils.Vector', v4: 'mathutils.Vector'):
+                        v3: 'mathutils.Vector',
+                        v4: 'mathutils.Vector') -> tuple:
     '''Returns a tuple with the points on each line respectively closest to the other. 
 
     :param v1: First point of the first line 
@@ -173,7 +173,7 @@ def intersect_line_sphere(line_a: 'mathutils.Vector',
                           line_b: 'mathutils.Vector',
                           sphere_co: 'mathutils.Vector',
                           sphere_radius,
-                          clip=True) -> 'mathutils.Vector':
+                          clip=True) -> tuple:
     '''Takes a line (as 2 points) and a sphere (as a point and a radius) and returns the intersection 
 
     :param line_a: First point of the line 
@@ -193,7 +193,7 @@ def intersect_line_sphere_2d(line_a: 'mathutils.Vector',
                              line_b: 'mathutils.Vector',
                              sphere_co: 'mathutils.Vector',
                              sphere_radius,
-                             clip=True) -> 'mathutils.Vector':
+                             clip=True) -> tuple:
     '''Takes a line (as 2 points) and a sphere (as a point and a radius) and returns the intersection 
 
     :param line_a: First point of the line 
@@ -209,10 +209,10 @@ def intersect_line_sphere_2d(line_a: 'mathutils.Vector',
     pass
 
 
-def intersect_plane_plane(
-        plane_a_co: 'mathutils.Vector', plane_a_no: 'mathutils.Vector',
-        plane_b_co: 'mathutils.Vector',
-        plane_b_no: 'mathutils.Vector') -> 'mathutils.Vector':
+def intersect_plane_plane(plane_a_co: 'mathutils.Vector',
+                          plane_a_no: 'mathutils.Vector',
+                          plane_b_co: 'mathutils.Vector',
+                          plane_b_no: 'mathutils.Vector') -> tuple:
     '''Return the intersection between two planes 
 
     :param plane_a_co: Point on the first plane 
@@ -230,7 +230,7 @@ def intersect_plane_plane(
 
 
 def intersect_point_line(pt: 'mathutils.Vector', line_p1: 'mathutils.Vector',
-                         line_p2) -> float:
+                         line_p2) -> typing.Union[float, 'mathutils.Vector']:
     '''Takes a point and a line and returns a tuple with the closest point on the line and its distance from the first point of the line as a percentage of the length of the line. 
 
     :param pt: Point 
@@ -328,7 +328,8 @@ def intersect_ray_tri(v1: 'mathutils.Vector',
 
 
 def intersect_sphere_sphere_2d(p_a: 'mathutils.Vector', radius_a: float,
-                               p_b: 'mathutils.Vector', radius_b: float):
+                               p_b: 'mathutils.Vector',
+                               radius_b: float) -> tuple:
     '''Returns 2 points on between intersecting circles. 
 
     :param p_a: Center of the first circle 
@@ -344,10 +345,11 @@ def intersect_sphere_sphere_2d(p_a: 'mathutils.Vector', radius_a: float,
     pass
 
 
-def normal(vectors) -> 'mathutils.Vector':
+def normal(vectors: list) -> 'mathutils.Vector':
     '''Returns the normal of a 3D polygon. 
 
     :param vectors: Vectors to calculate normals with 
+    :type vectors: list
     '''
 
     pass
